@@ -1,4 +1,4 @@
-__version__ = "0.1.0"
+__version__ = "0.1.17"
 
 from .connection import (
     public_websocket_connection,
@@ -6,26 +6,29 @@ from .connection import (
     wait_for_response,
 )
 
-from .connection.bundle import WebsocketBundle
-
 from .models import (
+    CryptodotcomRequestMessage,
     CryptodotcomResponseMessage,
     EnhancedWebsocket,
-    CryptodotcomRequestMessage,
     EnhancedWebsocketBehaviorSubject,
+    Order,
+    OrderSide,
+    OrderStatus,
+    OrderType,
+    WebsocketBundle,
 )
 from .events.ids import id_iterator
 from .events.methods import MethodName
 from .messages.listen import (
     keep_messages_only,
-    keep_status_only,
-    filter_new_socket_only,
+    keep_new_socket_only,
 )
 from .channels.ticker import subscribe_ticker
 
+from .operators import keep_response_messages_only, exclude_response_messages
+
 from .channels.open_orders import subscribe_open_orders, subscribe_open_orders_reload
-from .rest.user_open_orders import get_user_open_orders
-from .models import Order, OrderSide, OrderStatus, OrderType
+from .channels.orderbook import subscribe_order_book
 
 
 __all__ = [
@@ -33,10 +36,11 @@ __all__ = [
     "CryptodotcomResponseMessage",
     "EnhancedWebsocket",
     "EnhancedWebsocketBehaviorSubject",
-    "filter_new_socket_only",
+    "keep_new_socket_only",
+    "keep_response_messages_only",
+    "exclude_response_messages",
     "id_iterator",
     "keep_messages_only",
-    "keep_status_only",
     "MethodName",
     "Order",
     "OrderSide",
@@ -46,6 +50,7 @@ __all__ = [
     "public_websocket_connection",
     "subscribe_open_orders",
     "subscribe_ticker",
+    "subscribe_order_book",
     "subscribe_open_orders_reload",
     "get_user_open_orders",
     "WebsocketBundle",
