@@ -8,22 +8,25 @@ from reactivex.abc import SchedulerBase, ObserverBase
 from reactivex.scheduler import ThreadPoolScheduler
 from websocket import WebSocketConnectionClosedException, WebSocketApp
 
-from ..models.enhanced_websocket import EnhancedWebsocket
-from ..models.request import CryptodotcomRequestMessage
-from .bundle import WebsocketBundle
-from .message_types import WEBSOCKET_MESSAGE, WEBSOCKET_HEARTBEAT, WEBSOCKET_STATUS
-from .status import (
+from ..models import EnhancedWebsocket, CryptodotcomRequestMessage, WebsocketBundle
+from ..models.message_types import (
+    WEBSOCKET_MESSAGE,
+    WEBSOCKET_HEARTBEAT,
+    WEBSOCKET_STATUS,
+)
+from ..models.status import (
     WEBSOCKET_OPENED,
     WEBSOCKET_CLOSED,
-    Status,
 )
 from os import getenv
 
 logger = getLogger(__name__)
-raw_logger = getLogger(f'{__name__}.raw')
+raw_logger = getLogger(f"{__name__}.raw")
 
 USER_URL = getenv("CRYPTODOTCOM_USER_URL", "wss://stream.crypto.com/exchange/v1/user")
-MARKET_URL = getenv("CRYPTODOTCOM_MARKET_URL", "wss://stream.crypto.com/exchange/v1/market")
+MARKET_URL = getenv(
+    "CRYPTODOTCOM_MARKET_URL", "wss://stream.crypto.com/exchange/v1/market"
+)
 
 
 def raw_websocket_connection(
